Welcome to Savanna!
===================

Useful links
------------
.. toctree::
    :maxdepth: 1

    overview
    architecture
    devref/index
    quickstart

* `Savanna wiki <https://wiki.openstack.org/wiki/Savanna>`_
* `Savanna roadmap <https://wiki.openstack.org/wiki/Savanna/Roadmap>`_

.. include:: introduction.rst.inc

Project overview
----------------

.. toctree::
    :maxdepth: 1

    overview
    architecture

Developer Docs
--------------

.. toctree::
    :maxdepth: 3

    devref/index

.. toctree::
    :maxdepth: 1

    restapi/v02


Installation guides
-------------------

.. toctree::
    :maxdepth: 1

    installation.guide
    horizon/installation.guide